@@ -1,4 +1,6 @@
 from pytube import Playlist as ytPl, YouTube as yt
+from errors import *
+from youtubesearchpython import Search
 class Youtube:
     def getPlaylistInfo(playlistUrl:str):
         obj=ytPl(playlistUrl)
@@ -12,4 +14,9 @@ class Youtube:
         else: raise Exception("Unknown mode: "+mode)
     def getVideoInfo(videoUrl:str):
         obj=yt(videoUrl)
-        return obj.vid_info
\ No newline at end of file
+        return obj.vid_info
+    def search(term:str,limit:int=0):
+        allSearch = (Search(term, limit=limit))
+        turn = dict(allSearch.result()).get('result')
+        if not str(turn) == "{'result': []}":return turn
+        else:raise NothingFoundError('Found no YouTube video for term : ' + term)
\ No newline at end of file
